# This file was auto-generated by Fern from our API Definition.

import typing

Entities = typing.Union[
    typing.Literal[
        "generic",
        "unknown",
        "aircraft",
        "intellectual_property",
        "person",
        "vessel",
        "legal_matter",
        "security",
        "property",
        "company",
        "tradename",
        "shipment",
    ],
    typing.Any,
]
