# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
from ...generated_types.types.country import Country
from ...generated_types.types.risk import Risk
from .business_purpose import BusinessPurpose


class SourceOrDestinationEntity(pydantic_v1.BaseModel):
    id: str = pydantic_v1.Field()
    """
    Unique identifier of the entity
    """

    names: typing.List[str]
    risks: typing.Dict[Risk, typing.Any] = pydantic_v1.Field()
    """
    [Risks](/sayari-library/ontology/risk-factors)
    """

    business_purpose: typing.List[BusinessPurpose] = pydantic_v1.Field()
    """
    [Business Purpose](/sayari-library/ontology/enumerated-types#business-purpose-standard)
    """

    countries: typing.List[Country] = pydantic_v1.Field()
    """
    [Countries](/sayari-library/ontology/enumerated-types#country)
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
