# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError
from ..types.rate_limit_response import RateLimitResponse


class RateLimitExceeded(ApiError):
    def __init__(self, body: RateLimitResponse):
        super().__init__(status_code=429, body=body)
