# This file was auto-generated by Fern from our API Definition.

import typing

GetProjectEntitiesAcceptHeader = typing.Union[
    typing.Literal["application/json", "text/csv", "application/vnd.ms-excel"], typing.Any
]
