# This file was auto-generated by Fern from our API Definition.

import typing

from ...generated_types.types.risk import Risk
from .risk_data import RiskData

EntityRisk = typing.Dict[Risk, RiskData]
