# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError
from ..types.connection_error_response import ConnectionErrorResponse


class ConnectionError(ApiError):
    def __init__(self, body: ConnectionErrorResponse):
        super().__init__(status_code=520, body=body)
