# This file was auto-generated by Fern from our API Definition.

import typing

CountryContext = typing.Union[
    typing.Literal[
        "citizenship",
        "incorporation",
        "residence",
        "nationality",
        "address",
        "vessel_flag",
        "domicile",
        "shipment_departure",
        "shipment_arrival",
        "shipment_transit",
        "activity_in",
        "mentioned_in",
        "product_origin",
    ],
    typing.Any,
]
